*,:after,:before{box-sizing:border-box}body{background-color:transparent!important;color:#5a6674!important;font-size:13px;font-family:"Roboto",sans-serif}.search-form{position:relative;left:50%;width:90%;height:40px;border-radius:40px;box-shadow:0 6px 8px rgba(0,0,0,.15);-webkit-transform:translate(-50%);transform:translate(-50%);background:#fff;transition:all .3s ease;overflow:visible}.search-form.focus{box-shadow:0 3px 4px rgba(0,0,0,.15)}.search-input{position:absolute;top:10px;left:38px;font-size:14px;background:none;color:#5a6674;width:100%;height:20px;border:none;-webkit-appearance:none;appearance:none;outline:none}.search-input::-webkit-search-cancel-button{-webkit-appearance:none;appearance:none}.search-button{position:absolute;top:10px;left:15px;height:20px;width:20px;padding:0;margin:0;border:none;background:none;outline:none!important;cursor:pointer}.search-button svg{width:20px;height:20px;fill:#5a6674}.search-option{position:absolute;text-align:right;top:-4px;right:35px;border:none;outline:none}.search-option div{position:relative;display:inline-block;margin:0 1px;cursor:pointer}.search-option div button{position:absolute;top:0;left:0;background-color:transparent;border:none;outline:none;cursor:pointer}.search-option div svg{height:20px;width:20px;fill:#5a6674;opacity:.6;transition:all .2s ease-in-out;pointer-events:none}.search-option div .recording{fill:#e24040;opacity:1}.search-option div:hover svg{opacity:1}.dropdown{overflow:hidden}.dropdown,.spacer{display:flex;top:130%;flex-direction:column;border-radius:10px}.spacer{background-color:#fff;box-shadow:0 6px 8px rgba(0,0,0,.15)}.dropdown:empty{border:none}.dropdown-row{padding:10px;cursor:pointer;text-align:start;margin:0}.dropdown-row:hover{background-color:#eee}
/*# sourceMappingURL=main.74c77d57.chunk.css.map */